@@ -15,19 +15,31 @@ function (I, sec, mat, siga2, sige2)
             }
         }
         mattmp = siga2 * jmake(ss[i]) + sige2 * diag(rep(1, ss[i]))
-        see = eigen(mattmp, symmetric = T)$values
-        if (min(see) < 0) {
+        
+        eigs = eigen(mattmp, symmetric = T)
+        
+        if (min(eigs$values) < 0) {
             iflag = 1
         }
-        mattmp3 = sigma12i(mattmp)
+        
+        #mattmp3 = sigma12i(mattmp)
+        
+        mattmp3 = eigs$vectors %*% diag(1/eigs$values^0.5) %*% 
+          t(eigs$vectors)
+        
+        mattmp4 = eigs$vectors %*% diag(eigs$values^0.5) %*% 
+          t(eigs$vectors)
+        
         if (i == 1) {
             schpart = mattmp
             schpart12i = mattmp3
+            siggma = mattmp4
         }
         else {
             schpart = bdmake(schpart, mattmp)
             schpart12i = bdmake(schpart12i, mattmp3)
+            siggma = bdmake(siggma, mattmp4)
         }
     }
-    list(sigy2 = schpart, sigy12i = schpart12i, iflag = iflag)
+    list(sigy2 = schpart, sigy12i = schpart12i, iflag = iflag, siggma = siggma)
 }
