@@ -8,9 +8,16 @@ function (I, sec, mat, init = F, y, x, sigmaa2 = 1, sigmae2 = 1,
     }
     n = length(y)
     if (init == T) {
-        fitw = wwest(x, y, print.tbl = F)
-        theta = fitw$tmp1$coef
-        ehat = fitw$tmp1$residuals
+        #fitw = wwest(x, y, print.tbl = F)
+        
+        fit = minimize_dispersion(as.matrix(x), as.matrix(y))
+        
+        #theta = fitw$tmp1$coef
+        #ehat = fitw$tmp1$residuals
+        
+        theta = fit$theta
+        ehat = fit$ehat
+        
         fitvc = rprmeddis2(I, sec, mat, ehat, location, scale, 
             rprpair = rprpair)
         sigmaa2 = fitvc$siga2
@@ -23,8 +30,21 @@ function (I, sec, mat, init = F, y, x, sigmaa2 = 1, sigmae2 = 1,
         sigma12inv = matrix(sigmay$sigy12i, ncol = n)
         ystar = sigma12inv %*% y
         xstar = sigma12inv %*% cbind(rep(1, n), x)
-        fitw = wwest(xstar, ystar, print.tbl = F)
-        yhat = ystar - fitw$tmp1$residuals
+        
+        #fitw = wwest(xstar, ystar, print.tbl = F)
+        
+        fit = minimize_dispersion(as.matrix(xstar), as.matrix(ystar))
+        
+        #print(fitw$tmp1$coefficients)
+        #print(fit$theta)
+        
+        # Subtract intercept from residuals
+        fit.residuals = fit$ehat - fit$theta[1]
+        
+        #yhat = ystar - fitw$tmp1$residuals
+        yhat = ystar - fit.residuals
+        
+        
         fitcsp = projcsp(xstar, yhat)
         theta = fitcsp$betahat
         ehat = y - cbind(rep(1, n), x) %*% theta
